==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>El tiempo para autenticarse agotado</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>El disco está en uso, no se puede desmontar ahora</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>El disco está en uso, no se puede expulsar ahora</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>El disco está ocupado, no se puede expulsar ahora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>El dispositivo está ocupado, no se puede quitar ahora</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volumen %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>El dispositivo no fue retirado de forma segura</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clic en «Extraer del equipo» y luego desconéctelo</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">El disco está ocupado, no se puede expulsar ahora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">El dispositivo está ocupado, no se puede quitar ahora</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>No se puede desmontar el dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>El disco fue montado por el usuario «%1», no puedes desmontarlo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>No puedo encontrar el dispositivo montado</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discos</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Expulsar todo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>El dispositivo ha sido retirado de forma segura</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acceso denegado</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>No tienes permiso para acceder a esta carpeta</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Disco bajo escaneo, ¿desea detenerlo?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.3.orig.tar.xz: dde-file-manager-5.6.3/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>El tiempo para autenticarse agotado</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>El disco está en uso, no se puede desmontar ahora</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>El disco está en uso, no se puede expulsar ahora</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>El disco está ocupado, no se puede expulsar ahora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>El dispositivo está ocupado, no se puede quitar ahora</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volumen %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>El dispositivo no fue retirado de forma segura</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clic en «Extraer del equipo» y luego desconéctelo</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>No se puede desmontar el dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>El disco fue montado por el usuario «%1», no puedes desmontarlo.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>No puedo encontrar el dispositivo montado</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discos</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Expulsar todo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>El dispositivo ha sido retirado de forma segura</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acceso denegado</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>No tienes permiso para acceder a esta carpeta</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Disco bajo escaneo, ¿desea detenerlo?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Detener</translation>
    </message>
</context>
</TS>
